import { eq } from 'drizzle-orm';
import { db } from '..';
import { competitions } from '../schema/competitions';
import type { Round } from '../schema/rounds';

export async function getCompetitionWithAll(id: number) {
	return await db.query.competitions.findFirst({
		where: eq(competitions.id, id),
		with: {
			breakperiods: true,
			fields: true,
			rounds: {
				with: {
					matches: true
				}
			},
			teams: true
		}
	});
}

export async function getCompetitionsWithAll(skip: number = 0, take: number = 10) {
	return await db.query.competitions.findMany({
		orderBy: (competitions, { desc }) => [desc(competitions.start_date)],
		with: {
			breakperiods: true,
			fields: true,
			rounds: {
				with: {
					matches: true
				}
			},
			teams: true
		},
		limit: take,
		offset: skip
	});
}
