import { relations } from 'drizzle-orm';
import * as t from 'drizzle-orm/pg-core';
import { matches } from './matches';
import { competitions } from './competitions';
import { enumToPgEnum, SchedulingMode } from '../../../../types';

export const schedulingModes = t.pgEnum('scheduling_modes', enumToPgEnum(SchedulingMode));

export const rounds = t.pgTable('rounds', {
	id: t.serial('id').primaryKey(),
	nb_matches: t.integer('nb_matches').notNull(),
	competition_id: t.integer('competition_id').notNull(),
	scheduling_mode: schedulingModes('scheduling_modes')
});

export const roundsRelations = relations(rounds, ({ many, one }) => ({
	competition: one(competitions, {
		fields: [rounds.competition_id],
		references: [competitions.id]
	}),
	matches: many(matches)
}));

export type Round = typeof rounds.$inferSelect;

export type RoundInsert = typeof rounds.$inferInsert;
