import { insertRound } from '@/lib/server/db/queries/rounds';
import type { RequestHandler } from './$types';
import type { RoundInsert } from '@/lib/server/db/schema/rounds';
import { SchedulingMode } from '@/types';

export const POST: RequestHandler = async ({ request, params }) => {
	// get body from request
	// get competition id from url
	const body = await request.json();
	let competitionId;
	try {
		competitionId = Number.parseInt(params.id, 10);
	} catch {
		throw new Error('Invalid competition id');
	}
	if (competitionId === -1) {
		throw new Error('Invalid competition id');
	}

	console.log('body', body);
	console.log('competitionId', competitionId);

	let schedulingMode: SchedulingMode;

	try {
		schedulingMode = SchedulingMode[body.scheduling_mode as keyof typeof SchedulingMode];
	} catch {
		throw new Error('Invalid scheduling mode');
	}

	// create round
	const roundInsert: RoundInsert = {
		nb_matches: 0,
		competition_id: competitionId,
		scheduling_mode: schedulingMode
	};

	const round = await insertRound(competitionId, roundInsert);

	return new Response(JSON.stringify(round));
};
